@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V1.1.0-2
+# Application Name - Health Check V1.1.1-0
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -15,111 +15,46 @@
 #
 # Import the libraries needed in this program
 # import PyQt4 & sys
-print "** Start Imports **"
-print "** Importing qtcore & gui **"
-
+print "***** Start Imports *****"
 try:
+        print "** Importing qtcore & gui **"
 	from PyQt4 import QtCore, QtGui
-except:
-	print "Unexpected error: Importing QtCore and QtGui"
-	raise
-
-print "** Importing ui.touchstub - accuracy tool **"
-try:
+        print "** Importing ui.touchstub - accuracy tool **"
 	from ui.touchstub import aMainWindow
-except:
-	print "Unexpected error: Importing ui.touchstub (Accuracy test)"
-	raise
-
-print "** Importing sys **"
-try:
+        print "** Importing sys **"
 	import sys
+	print "** Importing commands **"
 	import commands
-except:
-	print "Unexpected error: Importing sys"
-	raise
-
-print "** Importing os **"
-try:
+	print "** Importing os **"  
 	import os
+	print "** Importing os.path **"
 	import os.path
-except:
-	print "Unexpected error: Importing os"
-	raise
-
-print "** Importing subprocess **"
-try:
+	print "** Importing subprocess **"
 	import subprocess
-except:
-	print "Unexpected error: Importing ui.touchstub (Accuracy test)"
-	raise
-
-print "** Importing dbus.glib **"
-try:
+        print "** Importing dbus.glib **"
 	import dbus.glib
-except:
-	print "Unexpected error: Importing dbus.glib"
-	raise
-
-print "** Importing Start location**"
-try:
+        print "** Importing Start location**"
 	import location
-except:
-	print "Unexpected error: Importing location"
-	raise
-
-print "** Importing Cellinfo **"
-try:
+        print "** Importing Cellinfo **"
 	import gn_cellinfo
-except:
-	print "Unexpected error: Importing gn_cellinfo"
-	raise
-
-print "** Importing Hildon **"
-try:
+        print "** Importing Hildon **"
 	import hildon
-except:
-	print "Unexpected error: Importing hildon"
-	raise
-
-print "** Importing Threading **"
-try:
+	print "** Importing Threading **"
 	from threading import Thread
-except:
-	print "Unexpected error: Importing Thread (from threading)"
-	raise
-
-print "** Importing Time **"
-try:
+	print "** Importing Time **"
 	import time
-except:
-	print "Unexpected error: Importing time"
-	raise
-
-print "** Importing GTK **"
-try:
+	print "** Importing GTK **"
 	import gtk
-except:
-	print "Unexpected error: Importing gtk"
-	raise
-
-print "** Initialize Threads **"
-try:
+        print "** Initialize Threads(GTK) **"
 	gtk.gdk.threads_init()
-except:
-	print "Unexpected error: Initializing Threads gtk.gdk.threads_init()"
-	raise
-
-print "** Importing Gobject **"
-try:
+        print "** Importing Gobject **"
 	import gobject
-except:
-	print "Unexpected error: Importing gobject"
-	raise
+	print "***** Finish Imports *****"
+except ImportError, err:
+        print "couldn't load module. %s" % (err)
+        sys.exit(2)
 
 
-print "** Finish Imports **"
-
 
 # Set a global variable - used to send the GPS info from a function back onto its label in the GUI. I'm sure there is a much better way returning
 # the variable in a function, but this works.... Example: http://www.wellho.net/resources/ex.php4?item=y105/locvar.py
@@ -373,6 +308,8 @@ class Ui_MainWindow(object):
 		# Set the Mainwindow to use this font
 		MainWindow.setFont(font)
 
+		
+
 
 
 		
@@ -397,10 +334,43 @@ class Ui_MainWindow(object):
 
 		# Creating the tab that i need for my application, and set it's size
 		self.tabWidget = QtGui.QTabWidget(self.centralwidget)
-		self.tabWidget.setGeometry(QtCore.QRect(0, 0, 800, 420))
+		self.tabWidget.setGeometry(QtCore.QRect(0, 0, 800, 429))
+		self.tabWidget.setStyleSheet("QTabWidget::pane { /* The tab widget frame */\
+     border-top: 0px solid #C2C7CB;\
+     position: absolute;\
+     top: -0.2em;\
+ }\
+\
+ QTabWidget::tab-bar {\
+     alignment: center;\
+ }\
+\
+ /* Style the tab using the tab sub-control. Note that\
+     it reads QTabBar _not_ QTabWidget */\
+ QTabBar::tab {\
+     background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,\
+                                 stop: 0 #006633, stop: 0.4 #006633,\
+                                 stop: 0.5 ##006633, stop: 1.0 #006633);\
+     border: 0px solid #C4C4C3;\
+     border-bottom-color: #C2C7CB; /* same as the pane color */\
+     border-top-left-radius: 2px;\
+     border-top-right-radius: 2px;\
+     min-width: 8ex;\
+     padding: 0px;\
+ }\
+\
+ QTabBar::tab:selected, QTabBar::tab:hover {\
+     background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,\
+                                 stop: 0 #fafafa, stop: 0.4 #f4f4f4,\
+                                 stop: 0.5 #e7e7e7, stop: 1.0 #fafafa);\
+ }\
+\
+ QTabBar::tab:selected {\
+     border-color: #9B9B9B;\
+     border-bottom-color: #C2C7CB; /* same as pane color */")
 		# Set the font size. I've gone for big... very big - so they are finger friendly.
 		font = QtGui.QFont()
-		font.setPointSize(28)
+		font.setPointSize(24)
 		self.tabWidget.setFont(font)
 		self.tabWidget.setObjectName("tabWidget")
 		self.tab = QtGui.QWidget()
@@ -418,8 +388,10 @@ class Ui_MainWindow(object):
 		self.listWidget.setSizePolicy(QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Minimum)
 		self.listWidget.setResizeMode(QtGui.QListView.Adjust)
 		QtCore.QObject.connect(self.listWidget, QtCore.SIGNAL("itemClicked(QListWidgetItem *)"), self.lclicked) 
+
+               
 		
-				
+		#QListView::item:selected:active {background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 #000000, stop: 1 #FFFFFF); }\		
 		# Draw the Tab Contents
 		self.tabWidget.addTab(self.tab, "")
 
@@ -540,7 +512,7 @@ class Ui_MainWindow(object):
 		# box of some sort
 		self.textBrowser = QtGui.QTextBrowser(self.tab_4)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-		self.textBrowser.setText (" Health Check V1.1.0-2 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec, Rob1n, Lcuk, W00t_ & MohammadAG.\n Many more people have helped by testing and offering support, so Thank You. \n \n April 2010.")
+		self.textBrowser.setText (" Health Check V1.1.1-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec, Rob1n, Lcuk, W00t_ & MohammadAG.\n Many more people have helped by testing and offering support, so Thank You. \n \n April 2010.")
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
@@ -577,7 +549,7 @@ class Ui_MainWindow(object):
                         b = os.popen('run-standalone.sh dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_device_orientation_ind').read()
                         coords = str(coords)
                         jaccel = str(coords) + str(b)
-                        self.listWidget.currentItem().setText("Accelerometer \t\t" + jaccel)
+                        self.listWidget.currentItem().setText("Accelerometer \t\t\t" + jaccel)
                 elif sela[0].strip() == "Battery Charge":
                         print " ** Getting battery charge**"
                         gl = os.popen('hal-device bme | awk \'/l.p/ {perc = $3}; /s_c/ {isch = $3} END if (isch == "false") {print perc" %"} else {print "Charging"}\'').read()
@@ -592,7 +564,7 @@ class Ui_MainWindow(object):
                         print " ** Getting Cam Shutter State**"
                         gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
                         gl = gl.strip()
-                        self.listWidget.currentItem().setText("Camera Shutter State \t" + gl.strip())
+                        self.listWidget.currentItem().setText("Camera Shutter State \t\t" + gl.strip())
                 elif sela[0].strip() == "FM Trans Strength":
                         print " ** Getting FM Transmitter power level **"
                         ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
@@ -607,7 +579,7 @@ class Ui_MainWindow(object):
                         print " ** Getting Keyboard Slider State**"
                         gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
                         gl = gl.strip()
-                        self.listWidget.currentItem().setText("Keyboard Slider State \t" + gl.strip())
+                        self.listWidget.currentItem().setText("Keyboard Slider State \t\t" + gl.strip())
                 elif sela[0].strip() == "Proximity Sensor State":
                         print " ** Getting proximity sensor state**"
                         gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
@@ -615,7 +587,7 @@ class Ui_MainWindow(object):
                         self.listWidget.currentItem().setText("Proximity Sensor State \t" + gl.strip())
                 elif sela[0].strip() == "System Uptime":
                         print " ** Getting system uptime**"
-                        ge = os.popen('uptime|cut -d" " -f4-|cut -d"," -f-1').read()
+                        ge = os.popen('uptime | sed -e \'s/.*p *//\' -e \'s/, l.*//\' -e \'s/  / /\'').read()
                         self.listWidget.currentItem().setText("System Uptime \t\t" + ge.strip())
                 elif sela[0].strip() == "CPU Current Freq":
                         print " ** Getting CPU Frequency **"
@@ -626,6 +598,80 @@ class Ui_MainWindow(object):
                         time.sleep(0.2)
                         gl = gl.strip()
                         self.listWidget.currentItem().setText("CPU Current Freq \t\t" + gl.strip())
+                elif sela[0].strip() == "App/Home % Used":
+                        print " ** Getting App Space **"
+                        gl = os.popen('df /home | awk \'/ho/ {print $5}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("App/Home % Used \t\t" + gl.strip())
+                elif sela[0].strip() == "App/Home Free":
+                        print " ** Getting App MB Free **"
+                        gl = os.popen('df -h /home | awk \'/ho/ {print $4}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("App/Home Free \t\t" + gl.strip())
+                elif sela[0].strip() == "Backlight Actual Level":
+                        print " ** Getting Backlight Info **"
+                        gl = os.popen('cat /sys/class/backlight/acx565akm/brightness').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Backlight Actual Level \t\t" + gl.strip())
+                elif sela[0].strip() == "Backlight Max Level":
+                        print " ** Getting Backlight Info MAX **"
+                        gl = os.popen('cat /sys/class/backlight/acx565akm/max_brightness').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Backlight Max Level \t\t" + gl.strip())
+                elif sela[0].strip() == "Battery Last Charge":
+                        print " ** Getting battery mAh info2**"
+                        gl = os.popen('hal-device bme | awk \'/g.la/ {print $3" mAh"}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Battery Last Charge \t\t" + gl.strip())
+                elif sela[0].strip() == "Boot Count":
+                        print " ** Getting boot count**"
+                        gd = os.popen('cat /var/lib/dsme/boot_count').read()
+                        gd = gd.strip()
+                        self.listWidget.currentItem().setText("Boot Count \t\t\t" + gd.strip())
+                elif sela[0].strip() == "Boot Reason":
+                        print " ** Getting Boot Reason**"
+                        gl = os.popen('cat /proc/bootreason').read()
+                        gl = gl.strip()	
+                        self.listWidget.currentItem().setText("Boot Reason \t\t\t" + gl.strip())
+                elif sela[0].strip() == "MMC Cover State":
+                        print " ** Getting MMC Cover/latch **"
+                        gl = os.popen('cat /sys/class/mmc_host/mmc0/cover_switch').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("MMC Cover State \t\t" + gl.strip())
+                elif sela[0].strip() == "Memory Card % Used":
+                        print " ** Getting MMC Space **"
+                        gl = os.popen('df /media/mmc1 | awk \'/mm/ {print $5}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Memory Card % Used \t\t" + gl.strip())
+                elif sela[0].strip() == "Memory Card Free":
+                        print " ** Getting MMC MB Free **"
+                        gl = os.popen('df -h /media/mmc1 | awk \'/mm/ {print $4}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Memory Card Free \t\t" + gl.strip())
+                elif sela[0].strip() == "MyDocs % Used":
+                        print " ** Getting myDocs % Used **"
+                        gl = os.popen('df /home/user/MyDocs | awk \'/My/ {print $5}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("MyDocs % Used \t\t" + gl.strip())
+                elif sela[0].strip() == "MyDocs Free":
+                        print " ** Getting myDocs MB Free **"
+                        gl = os.popen('df -h /home/user/MyDocs | awk \'/My/ {print $4}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("MyDocs Free \t\t\t" + gl.strip())
+                elif sela[0].strip() == "Rootfs % Used":
+                        print " ** Getting rootfs % used **"
+                        gl = os.popen('df | awk \'$1 == "rootfs" {print $5}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Rootfs % Used \t\t\t" + gl.strip())
+                elif sela[0].strip() == "Rootfs Free":
+                        print " ** Getting rootfs free MB **"
+                        gl = os.popen('df -h | awk \'$1 == "rootfs" {print $4}\'').read()
+                        gl = gl.strip()
+                        self.listWidget.currentItem().setText("Rootfs Free \t\t\t" + gl.strip())
+                elif sela[0].strip() == "System Load":
+                        print " ** Getting load from uptime**"
+                        ge = os.popen('uptime | sed \'s/.*e: //\'').read()
+                        self.listWidget.currentItem().setText("System Load \t\t\t" + ge.strip())
                 else:
                         print "else", sela[0].strip()
                 
@@ -657,9 +703,16 @@ class Ui_MainWindow(object):
 		igot = fh.readlines()
 		print " ** Adding CPUQ Frequencies **"
 		aa = ""
+		counter = 0
 		for line in igot:
                         s = line.split()
                         for words in s:
+                                counter = counter +1
+                                if counter == 5:
+                                        aa = str(aa) +"\n \t\t\t\t"
+                                if counter == 9:
+                                        aa = str(aa) +"\n \t\t\t\t"
+
                                 print words
                                 aa = str(aa) + str((int(words)/1000)) + "MHz, "
 
@@ -733,6 +786,7 @@ class Ui_MainWindow(object):
 		print " ** Getting firmware version **"
 		# This one reads fremantle version number (Firmware)
 		g = os.popen('dpkg -l "mp-fremantle-*"').read()
+
 		g = g.strip()[-15:]
 		g = str(g)
 		g.strip()
@@ -791,7 +845,7 @@ class Ui_MainWindow(object):
 		# This one reads fremantle version number (Firmware)
 		ga = os.popen('cat /proc/cpuinfo | grep Processor').read()
 		ga = ga.strip()[11:]		
-		self.listWidget.addItem("Processor Information \t" + ga.strip())
+		self.listWidget.addItem("Processor Information \t\t" + ga.strip())
 				
 		print " ** Getting board info**"
 		gb = os.popen('cat /proc/cpuinfo | grep Hardware').read()
@@ -801,12 +855,12 @@ class Ui_MainWindow(object):
 		print " ** Getting board info revision **"
 		gj = os.popen('cat /proc/cpuinfo | grep Revision').read()
 		gj = gj.strip()[11:]
-		self.listWidget.addItem("N900 Board Revision \t" + gj.strip())
+		self.listWidget.addItem("N900 Board Revision \t\t" + gj.strip())
 
 		print " ** Getting system locale**"
 		gc = os.popen('locale | grep LANG').read()
 		gc = gc.strip()[5:]
-		self.listWidget.addItem("System Locale \t\t" + gc.strip())
+		self.listWidget.addItem("System Locale \t\t\t" + gc.strip())
 
 		print " ** Getting boot count**"
 		gd = os.popen('cat /var/lib/dsme/boot_count').read()
@@ -826,12 +880,12 @@ class Ui_MainWindow(object):
 		print " ** Getting Cam Shutter State**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Camera Shutter State \t" + gl.strip())
+		self.listWidget.addItem("Camera Shutter State \t\t" + gl.strip())
 
 		print " ** Getting Keyboard Slider State**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Keyboard Slider State \t" + gl.strip())
+		self.listWidget.addItem("Keyboard Slider State \t\t" + gl.strip())
 
 		print " ** Getting proximity sensor state**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
@@ -853,6 +907,14 @@ class Ui_MainWindow(object):
 		gl = gl.strip()
 		self.listWidget.addItem("Battery Last Charge \t\t" + gl.strip())
 
+		print " ** Getting system uptime**"
+		ge = os.popen('uptime | sed -e \'s/.*p *//\' -e \'s/, l.*//\' -e \'s/  / /\'').read()
+		self.listWidget.addItem("System Uptime \t\t" + ge.strip())
+
+		print " ** Getting load from uptime**"
+		ge = os.popen('uptime | sed \'s/.*e: //\'').read()
+		self.listWidget.addItem("System Load \t\t\t" + ge.strip())
+
  
 		
 	def updatenetname(self):
@@ -904,14 +966,18 @@ class Ui_MainWindow(object):
 		gl = gl.strip()
 		self.listWidget2.addItem("MAC Address \t\t" + gl.strip())
 
+		print " ** Getting Bluetooth name **"
+		gl = os.popen('grep \'^Name =\' /etc/bluetooth/main.conf').read()
+		gl = gl.strip()[7:]
+		self.listWidget2.addItem("Bluetooth Name \t" + gl.strip())
 
-		
-	def updateUptime(self):
-		print " ** Getting system uptime**"
-		# This one reads fremantle version number (Firmware)
-		ge = os.popen('uptime|cut -d" " -f4-|cut -d"," -f-1').read()
-		self.listWidget.addItem("System Uptime \t\t" + ge.strip())
-
+                #print " ****************************************************"
+		#print " ** Getting external IP**"
+		#ge = os.popen('wget -q -O - api.myiptest.com | awk -F"\"" \'{print $4}\'').read()
+		#QtGui.QApplication.processEvents()
+                #time.sleep(2.5)
+		#self.listWidget2.addItem("External IP \t\t\t" + ge.strip())
+                
 
 	 
 
@@ -943,7 +1009,7 @@ class Ui_MainWindow(object):
 		coords = str(coords)
 		jaccel = str(coords) + str(b)
 		
-		self.listWidget.addItem("Accelerometer \t\t" + jaccel)
+		self.listWidget.addItem("Accelerometer \t\t\t" + jaccel)
 		
 		#Bluetooth
 		#print "performing inquiry..."
@@ -1011,7 +1077,7 @@ class Ui_MainWindow(object):
 		print " ** Getting rootfs % used **"
 		gl = os.popen('df | awk \'$1 == "rootfs" {print $5}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Rootfs % Used \t\t" + gl.strip())
+		self.listWidget.addItem("Rootfs % Used \t\t\t" + gl.strip())
 
 		print " ** Getting rootfs free MB **"
 		gl = os.popen('df -h | awk \'$1 == "rootfs" {print $4}\'').read()
@@ -1041,7 +1107,7 @@ class Ui_MainWindow(object):
 		print " ** Getting MMC Space **"
 		gl = os.popen('df /media/mmc1 | awk \'/mm/ {print $5}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Memory Card % Used \t" + gl.strip())
+		self.listWidget.addItem("Memory Card % Used \t\t" + gl.strip())
 
 		print " ** Getting MMC MB Free **"
 		gl = os.popen('df -h /media/mmc1 | awk \'/mm/ {print $4}\'').read()
@@ -1056,7 +1122,7 @@ class Ui_MainWindow(object):
 		print " ** Getting Backlight Info **"
 		gl = os.popen('cat /sys/class/backlight/acx565akm/brightness').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Backlight Actual Level \t" + gl.strip())
+		self.listWidget.addItem("Backlight Actual Level \t\t" + gl.strip())
 
 		print " ** Getting Backlight Info MAX **"
 		gl = os.popen('cat /sys/class/backlight/acx565akm/max_brightness').read()
@@ -1084,9 +1150,23 @@ class Ui_MainWindow(object):
 		progress.setAutoClose(True)
 		progress.setMinimum(0)
 		progress.setMaximum(100)
-		progress.resize(800,100)
+		progress.resize(800,220)
 		progress.setWindowTitle("Loading Healthcheck")
 		progress.show()
+
+                #progress.setlabel(QLabel*)
+		
+                #pbar = QtGui.QProgressBar(progress)
+                #progress.setBar(pbar)
+                #pbar.setMinimum(0)
+		#pbar.setMaximum(100)
+		#pbar.setValue(0)
+		
+                #fonta = QtGui.QFont()
+		#fonta.setPointSize(24)
+		#progress.setFont(fonta)
+		progress.setFont(QtGui.QFont('OldEnglish', 24,QtGui.QFont.Bold,QtGui.QFont.AllUppercase))
+
 		QtGui.QApplication.processEvents()
 		time.sleep(0.1)
                 progress.setValue(0)
@@ -1113,8 +1193,6 @@ class Ui_MainWindow(object):
                 QtGui.QApplication.processEvents()
                 time.sleep(0.1)
                 progress.setValue(60)
-                self.updateUptime()
-                progress.setWindowTitle("Loading Healthcheck - Uptime")
                 QtGui.QApplication.processEvents()
                 time.sleep(0.1)
                 progress.setValue(70)
@@ -1158,6 +1236,7 @@ class Ui_MainWindow(object):
 		progress.setMaximum(100)
 		progress.resize(800,200)
 		progress.setWindowTitle("Loading System")
+
 		progress.show()
 		QtGui.QApplication.processEvents()
 		time.sleep(0.5)
@@ -1185,7 +1264,7 @@ class Ui_MainWindow(object):
                 QtGui.QApplication.processEvents()
                 time.sleep(0.3)
                 progress.setValue(80)
-                self.updateUptime()
+                #self.updateUptime()
                 progress.setWindowTitle("Loading System - Uptime")
                 QtGui.QApplication.processEvents()
                 time.sleep(0.3)
@@ -1244,7 +1323,7 @@ class Ui_MainWindow(object):
 		
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.1.0-2", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.1.1-0", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
 		#self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
@@ -1298,7 +1377,7 @@ class Ui_MainWindow(object):
 		##
 		self.listWidget2.addItem("Cell Status \t\t" + status)
 		#self.lbl_pRNC_Info.setText(status)
-		self.listWidget2.addItem("Cell ID \t\t" + str(cell_id).strip())
+		self.listWidget2.addItem("Cell ID \t\t\t" + str(cell_id).strip())
 		#self.lbl_CellID_Info.setText(str(cell_id))
 
 		self.listWidget2.addItem("Cell Services \t\t" + services)
